==> chromium-141.0.7390.30-linux-testdata.tar.xz: chromium-141.0.7390.30/chrome/test/data/webui/glic/test_client/page_element_types.ts <==
// Copyright 2025 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

export interface PageElementTypes {
  content: HTMLElement;
  status: HTMLElement;
  pageHeader: HTMLElement;
  focusedFavicon: HTMLImageElement;
  focusedUrl: HTMLInputElement;
  contextAccessIndicator: HTMLInputElement;
  panelActiveCheckbox: HTMLInputElement;
  focusedFaviconV2: HTMLImageElement;
  focusedUrlV2: HTMLInputElement;
  focusedTabLogsV2: HTMLSpanElement;
  syncCookiesBn: HTMLButtonElement;
  testLogsBn: HTMLButtonElement;
  syncCookieStatus: HTMLSpanElement;
  getUserProfileInfoBn: HTMLButtonElement;
  getUserProfileInfoStatus: HTMLSpanElement;
  getUserProfileInfoImg: HTMLImageElement;
  changeProfileBn: HTMLButtonElement;
  testPermissionSwitch: HTMLButtonElement;
  openGlicSettings: HTMLButtonElement;
  openGlicSettingsHighlight: HTMLSelectElement;
  pageMetadataNames: HTMLInputElement;
  pageMetadataOpenTestPage: HTMLButtonElement;
  pageMetadataRefreshTabs: HTMLButtonElement;
  pageMetadataSection: HTMLFieldSetElement;
  pageMetadataResult: HTMLTextAreaElement;
  pageMetadataStatus: HTMLParagraphElement;
  pageMetadataSubscribe: HTMLButtonElement;
  pageMetadataTabsList: HTMLSelectElement;
  pageMetadataUnsubscribe: HTMLButtonElement;
  microphoneSwitch: HTMLInputElement;
  geolocationSwitch: HTMLInputElement;
  tabContextSwitch: HTMLInputElement;
  defaultTabContextSwitch: HTMLInputElement;
  newtabbn: HTMLButtonElement;
  reloadpage: HTMLButtonElement;
  getpagecontext: HTMLButtonElement;
  getPageContextResult: HTMLSpanElement;
  getPageContextStatus: HTMLSpanElement;
  URL: HTMLInputElement;
  innerTextCheckbox: HTMLInputElement;
  innerTextBytesLimit: HTMLInputElement;
  viewportScreenshotCheckbox: HTMLInputElement;
  pdfDataCheckbox: HTMLInputElement;
  annotatedPageContentCheckbox: HTMLInputElement;
  screenshotImg: HTMLImageElement;
  faviconImg: HTMLImageElement;
  getlocation: HTMLButtonElement;
  location: HTMLElement;
  locationStatus: HTMLDivElement;
  locationOsErrorUI: HTMLDivElement;
  locationGlicErrorUI: HTMLDivElement;
  openOsLocationSettingsButton: HTMLButtonElement;
  openOsMicrophoneSettings: HTMLButtonElement;
  openOsLocationSettings: HTMLButtonElement;
  openGlicLocationSettingsButton: HTMLButtonElement;
  permissionSelect: HTMLSelectElement;
  enabledSelect: HTMLSelectElement;
  closebn: HTMLButtonElement;
  shutdownbn: HTMLButtonElement;
  attachpanelbn: HTMLButtonElement;
  detachpanelbn: HTMLButtonElement;
  refreshbn: HTMLButtonElement;
  navigateWebviewUrl: HTMLInputElement;
  audioCapStop: HTMLButtonElement;
  audioCapStart: HTMLButtonElement;
  audioStatus: HTMLElement;
  mic: HTMLAudioElement;
  audioDuckingOn: HTMLButtonElement;
  audioDuckingOff: HTMLButtonElement;
  desktopScreenshot: HTMLButtonElement;
  desktopScreenshotImg: HTMLImageElement;
  desktopScreenshotErrorReason: HTMLSpanElement;
  panelScreenshot: HTMLButtonElement;
  createTabInBackground: HTMLInputElement;
  canAttachCheckbox: HTMLInputElement;
  scrollToDocumentId: HTMLSpanElement;
  scrollToURL: HTMLSpanElement;
  scrollToExactText: HTMLInputElement;
  scrollToExactTextSearchStart: HTMLSelectElement;
  scrollToFetchAPCBn: HTMLButtonElement;
  scrollToTextFragmentTextStart: HTMLInputElement;
  scrollToTextFragmentTextEnd: HTMLInputElement;
  scrollToTextFragmentSearchStart: HTMLSelectElement;
  scrollToNode: HTMLSelectElement;
  scrollToBn: HTMLButtonElement;
  fileDrop: HTMLDivElement;
  fileDropList: HTMLDivElement;
  showDirectoryPicker: HTMLButtonElement;
  failInitializationCheckbox: HTMLInputElement;
  screenWakeLockSwitch: HTMLInputElement;
  screenWakeLockStatus: HTMLLabelElement;
  setExperiment: HTMLButtonElement;
  trialName: HTMLInputElement;
  groupName: HTMLInputElement;
  setExperimentStatus: HTMLSpanElement;
  testClipboardSave: HTMLButtonElement;
  hangDuration: HTMLInputElement;
  hang: HTMLButtonElement;
  contentSizingTest: HTMLElement;
  enableTestSizingMode: HTMLButtonElement;
  disableTestSizingMode: HTMLButtonElement;
  enableDragResizeCheckbox: HTMLInputElement;
  growHeight: HTMLButtonElement;
  resetHeight: HTMLButtonElement;
  dump: HTMLElement;
  naturalSizing: HTMLInputElement;
  startMic: HTMLButtonElement;
  successUI: HTMLDivElement;
  localDenialUI: HTMLDivElement;
  osDenialUI: HTMLDivElement;
  openLocalSettingsButton: HTMLButtonElement;
  openOsSettingsButton: HTMLButtonElement;
  osGeolocationPermissionSwitch: HTMLInputElement;
  getOsMicrophonePermissionButton: HTMLButtonElement;
  osMicrophonePermissionResult: HTMLSpanElement;
  osGlicHotkey: HTMLInputElement;
  createActorTask: HTMLButtonElement;
  stopActorTask: HTMLButtonElement;
  actorTaskId: HTMLInputElement;
  executeAction: HTMLButtonElement;
  actionProtoEncodedText: HTMLInputElement;
  actionStatus: HTMLSpanElement;
  actionUpdatedContextResult: HTMLSpanElement;
  actionUpdatedScreenshotImg: HTMLImageElement;
  macOsPermissionsFieldset: HTMLFieldSetElement;
  attachmentControlsFieldset: HTMLFieldSetElement;
  closedCaptioningSwitch: HTMLInputElement;
  setClosedCaptioningTrue: HTMLButtonElement;
  setClosedCaptioningFalse: HTMLButtonElement;
  dropScrollToHighlightBtn: HTMLButtonElement;
  copyAPCToClipboardBtn: HTMLButtonElement;
  APCResult: HTMLSpanElement;
  maybeRefreshUserStatusBn: HTMLButtonElement;
  multiTabSection: HTMLElement;
  pinnedTabs: HTMLElement;
  pinFocusedTab: HTMLButtonElement;
  fetchPinned: HTMLButtonElement;
  shareCandidateQuery: HTMLInputElement;
  shareCandidates: HTMLElement;
  enableShareCandidates: HTMLInputElement;
  unpin: HTMLButtonElement;
  viewChangedBtn: HTMLButtonElement;
  viewChangedCurrentView: HTMLSelectElement;
  viewChangedAutomaticallyAccept: HTMLInputElement;
  mqlsClientIdBtn: HTMLButtonElement;
  multiTabFetchScreenshot: HTMLInputElement;
}

export const $: PageElementTypes = new Proxy({}, {
  get(_target: any, prop: string) {
    return document.getElementById(prop);
  },
});

==> chromium-142.0.7420.2-linux-testdata.tar.xz: chromium-142.0.7420.2/chrome/test/data/webui/glic/test_client/page_element_types.ts <==
// Copyright 2025 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

export interface PageElementTypes {
  content: HTMLElement;
  status: HTMLElement;
  pageHeader: HTMLElement;
  focusedFavicon: HTMLImageElement;
  focusedUrl: HTMLInputElement;
  contextAccessIndicator: HTMLInputElement;
  panelActiveCheckbox: HTMLInputElement;
  focusedFaviconV2: HTMLImageElement;
  focusedUrlV2: HTMLInputElement;
  focusedTabLogsV2: HTMLSpanElement;
  syncCookiesBn: HTMLButtonElement;
  testLogsBn: HTMLButtonElement;
  syncCookieStatus: HTMLSpanElement;
  getUserProfileInfoBn: HTMLButtonElement;
  getUserProfileInfoStatus: HTMLSpanElement;
  getUserProfileInfoImg: HTMLImageElement;
  changeProfileBn: HTMLButtonElement;
  testPermissionSwitch: HTMLButtonElement;
  openGlicSettings: HTMLButtonElement;
  openGlicSettingsHighlight: HTMLSelectElement;
  pageMetadataNames: HTMLInputElement;
  pageMetadataOpenTestPage: HTMLButtonElement;
  pageMetadataRefreshTabs: HTMLButtonElement;
  pageMetadataSection: HTMLFieldSetElement;
  pageMetadataResult: HTMLTextAreaElement;
  pageMetadataStatus: HTMLParagraphElement;
  pageMetadataSubscribe: HTMLButtonElement;
  pageMetadataTabsList: HTMLSelectElement;
  pageMetadataUnsubscribe: HTMLButtonElement;
  microphoneSwitch: HTMLInputElement;
  geolocationSwitch: HTMLInputElement;
  tabContextSwitch: HTMLInputElement;
  defaultTabContextSwitch: HTMLInputElement;
  newtabbn: HTMLButtonElement;
  reloadpage: HTMLButtonElement;
  getpagecontext: HTMLButtonElement;
  getPageContextResult: HTMLSpanElement;
  getPageContextStatus: HTMLSpanElement;
  URL: HTMLInputElement;
  innerTextCheckbox: HTMLInputElement;
  innerTextBytesLimit: HTMLInputElement;
  viewportScreenshotCheckbox: HTMLInputElement;
  pdfDataCheckbox: HTMLInputElement;
  annotatedPageContentCheckbox: HTMLInputElement;
  screenshotImg: HTMLImageElement;
  faviconImg: HTMLImageElement;
  getlocation: HTMLButtonElement;
  location: HTMLElement;
  locationStatus: HTMLDivElement;
  locationOsErrorUI: HTMLDivElement;
  locationGlicErrorUI: HTMLDivElement;
  openOsLocationSettingsButton: HTMLButtonElement;
  openOsMicrophoneSettings: HTMLButtonElement;
  openOsLocationSettings: HTMLButtonElement;
  openGlicLocationSettingsButton: HTMLButtonElement;
  permissionSelect: HTMLSelectElement;
  enabledSelect: HTMLSelectElement;
  closebn: HTMLButtonElement;
  shutdownbn: HTMLButtonElement;
  attachpanelbn: HTMLButtonElement;
  detachpanelbn: HTMLButtonElement;
  refreshbn: HTMLButtonElement;
  navigateWebviewUrl: HTMLInputElement;
  audioCapStop: HTMLButtonElement;
  audioCapStart: HTMLButtonElement;
  audioStatus: HTMLElement;
  mic: HTMLAudioElement;
  audioDuckingOn: HTMLButtonElement;
  audioDuckingOff: HTMLButtonElement;
  desktopScreenshot: HTMLButtonElement;
  desktopScreenshotImg: HTMLImageElement;
  desktopScreenshotErrorReason: HTMLSpanElement;
  panelScreenshot: HTMLButtonElement;
  createTabInBackground: HTMLInputElement;
  canAttachCheckbox: HTMLInputElement;
  scrollToDocumentId: HTMLSpanElement;
  scrollToURL: HTMLSpanElement;
  scrollToExactText: HTMLInputElement;
  scrollToExactTextSearchStart: HTMLSelectElement;
  scrollToFetchAPCBn: HTMLButtonElement;
  scrollToTextFragmentTextStart: HTMLInputElement;
  scrollToTextFragmentTextEnd: HTMLInputElement;
  scrollToTextFragmentSearchStart: HTMLSelectElement;
  scrollToNode: HTMLSelectElement;
  scrollToBn: HTMLButtonElement;
  fileDrop: HTMLDivElement;
  fileDropList: HTMLDivElement;
  showDirectoryPicker: HTMLButtonElement;
  failInitializationCheckbox: HTMLInputElement;
  screenWakeLockSwitch: HTMLInputElement;
  screenWakeLockStatus: HTMLLabelElement;
  setExperiment: HTMLButtonElement;
  trialName: HTMLInputElement;
  groupName: HTMLInputElement;
  setExperimentStatus: HTMLSpanElement;
  testClipboardSave: HTMLButtonElement;
  hangDuration: HTMLInputElement;
  hang: HTMLButtonElement;
  contentSizingTest: HTMLElement;
  enableTestSizingMode: HTMLButtonElement;
  disableTestSizingMode: HTMLButtonElement;
  enableDragResizeCheckbox: HTMLInputElement;
  growHeight: HTMLButtonElement;
  resetHeight: HTMLButtonElement;
  dump: HTMLElement;
  naturalSizing: HTMLInputElement;
  startMic: HTMLButtonElement;
  successUI: HTMLDivElement;
  localDenialUI: HTMLDivElement;
  osDenialUI: HTMLDivElement;
  openLocalSettingsButton: HTMLButtonElement;
  openOsSettingsButton: HTMLButtonElement;
  osGeolocationPermissionSwitch: HTMLInputElement;
  getOsMicrophonePermissionButton: HTMLButtonElement;
  osMicrophonePermissionResult: HTMLSpanElement;
  osGlicHotkey: HTMLInputElement;
  createActorTask: HTMLButtonElement;
  stopActorTask: HTMLButtonElement;
  actorTaskId: HTMLInputElement;
  executeAction: HTMLButtonElement;
  actionProtoEncodedText: HTMLInputElement;
  actionStatus: HTMLSpanElement;
  actionUpdatedContextResult: HTMLSpanElement;
  actionUpdatedScreenshotImg: HTMLImageElement;
  macOsPermissionsFieldset: HTMLFieldSetElement;
  attachmentControlsFieldset: HTMLFieldSetElement;
  closedCaptioningSwitch: HTMLInputElement;
  setClosedCaptioningTrue: HTMLButtonElement;
  setClosedCaptioningFalse: HTMLButtonElement;
  dropScrollToHighlightBtn: HTMLButtonElement;
  copyAPCToClipboardBtn: HTMLButtonElement;
  APCResult: HTMLSpanElement;
  maybeRefreshUserStatusBn: HTMLButtonElement;
  multiTabSection: HTMLElement;
  pinnedTabs: HTMLElement;
  pinFocusedTab: HTMLButtonElement;
  fetchPinned: HTMLButtonElement;
  shareCandidateQuery: HTMLInputElement;
  shareCandidates: HTMLElement;
  enableShareCandidates: HTMLInputElement;
  unpin: HTMLButtonElement;
  viewChangedBtn: HTMLButtonElement;
  viewChangedCurrentView: HTMLSelectElement;
  viewChangedAutomaticallyAccept: HTMLInputElement;
  mqlsClientIdBtn: HTMLButtonElement;
  multiTabFetchScreenshot: HTMLInputElement;
  conversationIdInput: HTMLInputElement;
  switchConversationBtn: HTMLButtonElement;
  registerConversationBtn: HTMLButtonElement;
  conversationId: HTMLInputElement;
}

export const $: PageElementTypes = new Proxy({}, {
  get(_target: any, prop: string) {
    return document.getElementById(prop);
  },
});
